﻿using MongoDB.Driver;
using System;
using System.Collections.Generic;
using YamlDotNet.Serialization;

namespace MongoExpressionConvert
{
    class Program
    {
        static void Main(string[] args)
        {
            IMongoClient mongoClient = new MongoClient(@"mongodb://127.0.0.1:27017/admin");

            IMongoDatabase db = mongoClient.GetDatabase("InformalSchool");

            IMongoCollection<Student> personsCollection = db.GetCollection<Student>("Persons");
            IMongoCollection<ClassRoom> classCollection = db.GetCollection<ClassRoom>("ClassRooms");

            personsCollection.DeleteMany(x => true);
            classCollection.DeleteMany(x => true);

            Guid student1Id = Guid.Parse("313514c1-420a-4177-98a2-e6ca4b5d6693");
            Guid student2Id = Guid.Parse("37b8b5a5-555c-4ec8-bb40-20a185de8624");
            Guid student3Id = Guid.Parse("b03c062c-f5dd-4e4a-b668-f9c83c2b914d");
            Guid classId = Guid.Parse("518a3918-22c7-4f46-839f-b40666d35c4f");

            var classRoom = new ClassRoom("Introduction in .NET", classId);
            var student1 = new Student("John", "Doe", student1Id);
            var student2 = new Student("Jack", "Doe", student2Id);
            var student3 = new Student("Anne", "Doe", student3Id);
            
            classRoom.Enroll(student1);
            classRoom.Enroll(student2);
            classRoom.Enroll(student3);

            personsCollection.InsertMany(new List<Student> { student1, student2, student3 });
            classCollection.InsertOne(classRoom);

            List<Student> persons = personsCollection
                .Find(CustomFilter<Student>.Equal(x => x.FirstName, "Jack").GetMongoFilter())
                .ToList();

            List<ClassRoom> classRooms = classCollection
                .Find(CustomFilter<ClassRoom>
                    .ListContains(x => x.Enrolled, student1Id)
                    .GetMongoFilter())
                .ToList();

            Print(persons);
            Print(classRooms);
            Console.ReadKey();
        }

        static void Print(object graph)
        {
            Serializer serializer = new Serializer();
            Console.WriteLine(serializer.Serialize(graph));
        }
    }
}
